Kundenkonto - Rakuten.de

- Bestell-Hotline: 0951 / 408 39 100

## Rakuten Superpunkte

## Kundenkonto

Login / Anmeldung
Bestellstatus
Superpunkte Vorteile
Superpunkte Aktionen
Passwort vergessen
Newsletter
Meine Merkliste
Zuletzt angesehene Artikel
Meine Lieblingsshops

## Infocenter

Kundenservice & Kontakt
Versandkosten & Lieferung
Zahlungsarten

## Rechtliches

Impressum
Nutzungsbedingungen
Datenschutz
Gesetzliche Informationen

# Login für Rakuten Kunden

Geben Sie Ihre E-Mail-Adresse oder Ihre Rakuten User ID und Ihr Passwort ein, um sich mit Ihrem Kundenkonto einzuloggen.
( Passwort vergessen? )

E-Mail-Adresse oder Rakuten User ID: |
Passwort: |

# Sie haben noch kein Rakuten Kundenkonto?

Eröffnen Sie jetzt ganz einfach Ihr Kundenkonto und nutzen Sie künftig alle Vorteile:

- 500 Superpunkte gratis Belohnung für Ihre erste Bestellung!
- Automatisch bei jedem Einkauf Superpunkte bekommen und sparen!
- Mit Ihrem Kundenkonto in über 5.172 Shops bestellen
- Bequem den Status Ihrer Bestellungen abfragen
- Gespeicherte Lieblingsshops jederzeit wiederfinden
- Tolle Artikel dauerhaft auf Ihrer Merkliste speichern

Anrede: | Frau Herr
Vorname: |
Nachname: |
Ihre E-Mail Adresse: |
E-Mail Adresse bestätigen: |
Gewünschtes Passwort: |
Passwort bestätigen: |

| Ich möchte gerne regelmäßig über aktuelle Shopping-Angebote und Bonus-Aktionen per E-Mail informiert werden.

Alle Informationen zur Speicherung Ihrer Daten entnehmen Sie bitte unserem Hinweis zum Datenschutz

# Rakuten Superpunkte

Mit einem Kundenkonto bei Rakuten sammeln Sie bei jedem Einkauf automatisch Superpunkte, die Sie ganz einfach bei der nächsten Bestellung einlösen und viel Geld sparen können!

# Lieblingsshops

Sie haben einen ganz besonderen Shop bei Rakuten entdeckt? Dann speichern Sie ihn doch in Ihrem Kundenkonto! So finden Sie Ihren neuen Lieblingsshop jederzeit und ohne Aufwand wieder!

# Bestellübersicht

Haben Sie all Ihre Rakuten Bestellungen immer übersichtlich im Blick!

# Merkliste

In Ihrem Rakuten Kundenkonto können Sie alle Ihre Wunschprodukte dauerhaft speichern. So bleiben Ihre Wünsche einfach unvergessen!

# Komfortabler bestellen

Nie wieder lästige Adresseingabe mit einem Rakuten Kundenkonto!
Einfach anmelden und bestellen!

# 500 Superpunkte

Für Ihre erste Bestellung über ein Rakuten Kundenkonto erhalten Sie als Dankeschön zusätzlich 500 Superpunkte (entspricht 5 €) von uns geschenkt!